# python-cabarchive

Contributors welcome, either adding new functionality or fixing bugs.

See also: https://msdn.microsoft.com/en-us/library/bb417343.aspx

# Release Process

These notes are probably only for the maintainer of this module!

    make pkg
    ./env/bin/twine upload dist/*
